@@ -18,6 +18,10 @@ import serial
 from serial.tools.list_ports import comports
 from serial.tools import hexlify_codec
 
+import time
+from pathlib import Path
+import re
+
 # pylint: disable=wrong-import-order,wrong-import-position
 
 codecs.register(lambda c: hexlify_codec.getregentry() if c == 'hexlify' else None)
@@ -438,6 +442,11 @@ class Miniterm(object):
     def start(self):
         """start worker threads"""
         self.alive = True
+        logdir = os.path.join(str(Path.home()), 'xMesh-Assistant')
+        if not os.path.exists(logdir):
+            os.mkdir(logdir)
+        self.logpath = os.path.join(logdir, f'{time.strftime("%Y-%m-%d_%H:%M:%S", time.localtime())}.raw')
+        self.logfile = open(self.logpath, 'w')
         self._start_reader()
         # enter console->serial loop
         self.transmitter_thread = threading.Thread(target=self.writer, name='tx')
@@ -511,11 +520,12 @@ class Miniterm(object):
                 if data:
                     if self.raw:
                         self.console.write_bytes(data)
+                        self.logfile.write(data.decode())
                     else:
                         text = self.rx_decoder.decode(data)
                         for transformation in self.rx_transformations:
                             text = transformation.rx(text)
-                        self.console.write(text)
+                            self.console.write(text)
         except serial.SerialException:
             self.alive = False
             self.console.cancel()
@@ -832,7 +842,7 @@ def main(default_type='sniffer', default_port=None, default_baudrate=921600, def
     import argparse
 
     parser = argparse.ArgumentParser(
-        description='Miniterm - A simple terminal program for the serial port.')
+        description='xMesh - xMesh Assistant.')
 
     parser.add_argument(
         'type',
@@ -1041,7 +1051,7 @@ def main(default_type='sniffer', default_port=None, default_baudrate=921600, def
     miniterm.set_tx_encoding(args.serial_port_encoding)
 
     if not args.quiet:
-        sys.stderr.write('--- Miniterm on {p.name}  {p.baudrate},{p.bytesize},{p.parity},{p.stopbits} ---\n'.format(
+        sys.stderr.write('--- xMesh Assistant on {p.name}  {p.baudrate},{p.bytesize},{p.parity},{p.stopbits} ---\n'.format(
             p=miniterm.serial))
         sys.stderr.write('--- Quit: {} | Menu: {} | Help: {} followed by {} ---\n'.format(
             key_description(miniterm.exit_character),
@@ -1056,6 +1066,13 @@ def main(default_type='sniffer', default_port=None, default_baudrate=921600, def
         pass
     if not args.quiet:
         sys.stderr.write('\n--- exit ---\n')
+        miniterm.logfile.close()
+        ansi_escape = re.compile(r'\x1B(?:[@-Z\\-_]|\[[0-?]*[ -/]*[@-~])')
+        with open(miniterm.logpath.replace('.raw', '.log'), 'w') as logfile:
+            with open(miniterm.logpath, 'r') as rawfile:
+                for line in rawfile:
+                    logfile.write(ansi_escape.sub('', line))
+        os.remove(miniterm.logpath)
     miniterm.join()
     miniterm.close()
 
